@@ -13,10 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import print_function
-
 import collections
+from io import BytesIO
 import json
+from muranopkgcheck import manager as check_manager
+from muranopkgcheck import pkg_loader as check_pkg_loader
+from muranopkgcheck import validators as check_validators
 import os
 import re
 import shutil
@@ -30,11 +32,11 @@ import zipfile
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
-from oslo_utils import importutils
+from oslo_utils import uuidutils
+
 import prettytable
 import requests
-import six
-from six.moves import urllib
+import urllib
 import yaml
 import yaql
 
@@ -93,8 +95,7 @@ def print_list(objs, fields, field_labels, formatters=None, sortby=0):
 
     result = encodeutils.safe_encode(pt.get_string())
 
-    if six.PY3:
-        result = result.decode()
+    result = result.decode()
 
     print(result)
 
@@ -113,8 +114,7 @@ def print_dict(d, formatters=None):
 
     result = encodeutils.safe_encode(pt.get_string(sortby='Property'))
 
-    if six.PY3:
-        result = result.decode()
+    result = result.decode()
 
     print(result)
 
@@ -161,13 +161,6 @@ def env(*vars, **kwargs):
     return kwargs.get('default', '')
 
 
-def import_versioned_module(version, submodule=None):
-    module = 'muranoclient.v%s' % version
-    if submodule:
-        module = '.'.join((module, submodule))
-    return importutils.import_module(module)
-
-
 def exit(msg=''):
     if msg:
         print(encodeutils.safe_encode(msg), file=sys.stderr)
@@ -190,13 +183,10 @@ def getsockopt(self, *args, **kwargs):
 
 def exception_to_str(exc):
     try:
-        error = six.text_type(exc)
+        error = str(exc)
     except UnicodeError:
-        try:
-            error = str(exc)
-        except UnicodeError:
-            error = ("Caught '%(exception)s' exception." %
-                     {"exception": exc.__class__.__name__})
+        error = ("Caught '%(exception)s' exception." %
+                 {"exception": exc.__class__.__name__})
     return encodeutils.safe_encode(error, errors='ignore')
 
 
@@ -227,6 +217,16 @@ class File(object):
         else:
             if os.path.isfile(self.name):
                 return open(self.name, mode)
+            if os.path.isdir(self.name):
+                tmp = tempfile.NamedTemporaryFile()
+                archive = zipfile.ZipFile(tmp, 'w', zipfile.ZIP_DEFLATED)
+                for root, dirs, files in os.walk(self.name):
+                    for _file in files:
+                        destination = os.path.relpath(
+                            os.path.join(root, _file), os.path.join(self.name))
+                        archive.write(os.path.join(root, _file), destination)
+                tmp.flush()
+                return open(tmp.name, mode)
             url = urllib.parse.urlparse(self.name)
             if url.scheme in ('http', 'https'):
                 resp = requests.get(self.name, stream=True)
@@ -297,7 +297,11 @@ class Package(FileWrapperMixin):
     def from_file(file_obj):
         if not isinstance(file_obj, File):
             file_obj = File(file_obj)
-        return Package(file_obj)
+        pkg = Package(file_obj)
+        errs = pkg.validate()
+        if errs:
+            raise exceptions.HTTPBadRequest(details=errs)
+        return pkg
 
     @staticmethod
     def fromFile(file_obj):
@@ -332,6 +336,16 @@ class Package(FileWrapperMixin):
             extension='.zip')
         )
 
+    def validate(self):
+        m = check_manager.Manager(self._file,
+                                  loader=check_pkg_loader.ZipLoader)
+        errors = m.validate(
+            validators=[check_validators.manifest.ManifestValidator],
+            only_errors=True)
+        if errors:
+            fmt = check_manager.PlainTextFormatter().format
+            return 'Invalid Murano package\n{}\n'.format(fmt(errors))
+
     @property
     def contents(self):
         """Contents of a package."""
@@ -339,7 +353,7 @@ class Package(FileWrapperMixin):
             try:
                 self._file.seek(0)
                 self._zip_obj = zipfile.ZipFile(
-                    six.BytesIO(self._file.read()))
+                    BytesIO(self._file.read()))
             except Exception as e:
                 LOG.error("Error {0} occurred,"
                           " while parsing the package".format(e))
@@ -380,8 +394,8 @@ class Package(FileWrapperMixin):
         if not hasattr(self, '_classes'):
             self._classes = {}
             self._resolvers = {}
-            for class_name, class_file in six.iteritems(
-                    self.manifest.get('Classes', {})):
+            for class_name, class_file in (
+                    self.manifest.get('Classes', {}).items()):
                 filename = "Classes/%s" % class_file
                 if filename not in self.contents.namelist():
                     continue
@@ -447,7 +461,7 @@ class Package(FileWrapperMixin):
 
         def transpose_graph(graph):
             transposed = collections.defaultdict(list)
-            for node, deps in six.viewitems(graph):
+            for node, deps in graph.items():
                 for dep in deps:
                     transposed[dep].append(node)
             return transposed
@@ -506,7 +520,7 @@ class Package(FileWrapperMixin):
     def _get_direct_deps(package, base_url, path):
         result = []
         if 'Require' in package.manifest:
-            for dep_name, ver in six.iteritems(package.manifest['Require']):
+            for dep_name, ver in package.manifest['Require'].items():
                 try:
                     req_file = Package.from_location(
                         dep_name,
@@ -566,7 +580,7 @@ def ensure_images(glance_client, image_specs, base_url,
         for key in keys:
             if key not in image:
                 LOG.warning("Image specification invalid: "
-                            "No {0} key in image ".format(key))
+                            "No {0} key in image ").format(key)
                 return False
         return True
 
@@ -722,6 +736,7 @@ class DummyYaqlYamlLoader(yaml.SafeLoader):
     """Constructor that treats !yaql as string."""
     pass
 
+
 DummyYaqlYamlLoader.add_constructor(
     u'!yaql', DummyYaqlYamlLoader.yaml_constructors[u'tag:yaml.org,2002:str'])
 
@@ -729,6 +744,7 @@ DummyYaqlYamlLoader.add_constructor(
 class YaqlYamlLoader(yaml.SafeLoader):
     pass
 
+
 # workaround for PyYAML bug: http://pyyaml.org/ticket/221
 resolvers = {}
 for k, v in yaml.SafeLoader.yaml_implicit_resolvers.items():
@@ -740,6 +756,7 @@ def yaql_constructor(loader, node):
     value = loader.construct_scalar(node)
     return YaqlExpression(value)
 
+
 YaqlYamlLoader.add_constructor(u'!yaql', yaql_constructor)
 YaqlYamlLoader.add_implicit_resolver(u'!yaql', YaqlExpression, None)
 
@@ -750,21 +767,23 @@ def traverse_and_replace(obj,
     """Helper function that traverses object model and substitutes ids.
 
     Recursively checks values of objects found in `obj` against `pattern`,
-    and replaces strings that match pattern with uuid.uuid4(). Keeps track of
-    any replacements already made, i.e. ===id1=== would always be the same,
-    across `obj`. Uses 1st group, found in the `pattern` regexp as unique
-    identifier of a replacement
+    and replaces strings that match pattern with uuidutils.generate_uuid().
+    Keeps track of any replacements already made, i.e. ===id1=== would
+    always be the same, across `obj`. Uses 1st group, found in the `pattern`
+    regexp as unique identifier of a replacement
     """
     if replacements is None:
-        replacements = collections.defaultdict(lambda: uuid.uuid4().hex)
+        replacements = collections.defaultdict(
+            lambda: uuidutils.generate_uuid(dashed=False))
 
     def _maybe_replace(obj, key, value):
         """Check and replace value against pattern"""
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             m = pattern.search(value)
             if m:
                 if m.group(1) not in replacements:
-                    replacements[m.group(1)] = uuid.uuid4().hex
+                    replacements[m.group(1)] = uuidutils.generate_uuid(
+                        dashed=False)
                 obj[key] = replacements[m.group(1)]
 
     if isinstance(obj, list):
