@@ -16,8 +16,6 @@
 Command-line interface to the Murano Project.
 """
 
-from __future__ import print_function
-
 import argparse
 import sys
 
@@ -30,14 +28,15 @@ from keystoneclient import session as ksession
 from oslo_log import handlers
 from oslo_log import log as logging
 from oslo_utils import encodeutils
-import six
-import six.moves.urllib.parse as urlparse
+from oslo_utils import importutils
+import urllib.parse as urlparse
 
 import muranoclient
+from muranoclient.apiclient import exceptions as exc
 from muranoclient import client as murano_client
 from muranoclient.common import utils
 from muranoclient.glance import client as art_client
-from muranoclient.openstack.common.apiclient import exceptions as exc
+
 
 logger = logging.getLogger(__name__)
 
@@ -47,7 +46,7 @@ DEFAULT_REPO_URL = "http://apps.openstack.org/api/v1/murano_repo/liberty/"
 # quick local fix for keystoneclient bug which blocks built-in reauth
 # functionality in case of expired token.
 # bug: https://bugs.launchpad.net/python-keystoneclient/+bug/1551392
-# fix: https://review.openstack.org/#/c/286236/
+# fix: https://review.opendev.org/#/c/286236/
 class AuthCLI(DefaultCLI):
     def invalidate(self):
         retval = super(AuthCLI, self).invalidate()
@@ -65,7 +64,7 @@ class MuranoShell(object):
 
         identity.Password.register_argparse_arguments(parser)
 
-    def get_base_parser(self):
+    def get_base_parser(self, argv):
 
         parser = argparse.ArgumentParser(
             prog='murano',
@@ -95,20 +94,6 @@ class MuranoShell(object):
                             default=False, action="store_true",
                             help="Print more verbose output.")
 
-        # os-cert, os-key, insecure, ca-file are all added
-        # by keystone session register_cli_opts later
-        parser.add_argument('--cert-file',
-                            dest='os_cert',
-                            help='DEPRECATED! Use --os-cert.')
-
-        parser.add_argument('--key-file',
-                            dest='os_key',
-                            help='DEPRECATED! Use --os-key.')
-
-        parser.add_argument('--ca-file',
-                            dest='os_cacert',
-                            help='DEPRECATED! Use --os-cacert.')
-
         parser.add_argument('--api-timeout',
                             help='Number of seconds to wait for an '
                                  'API response, '
@@ -183,32 +168,41 @@ class MuranoShell(object):
                                  'Defaults to env[MURANO_PACKAGES_SERVICE] or '
                                  'to "murano"')
 
+        # The following 3 arguments are deprecated and are all added
+        # by keystone session register_cli_opts later.  Only add these
+        # arguments if they are present on the command line.
+
+        if '--cert-file' in argv:
+            parser.add_argument('--cert-file',
+                                dest='os_cert',
+                                help='DEPRECATED! Use --os-cert.')
+
+        if '--key-file' in argv:
+            parser.add_argument('--key-file',
+                                dest='os_key',
+                                help='DEPRECATED! Use --os-key.')
+
+        if '--ca-file' in argv:
+            parser.add_argument('--ca-file',
+                                dest='os_cacert',
+                                help='DEPRECATED! Use --os-cacert.')
+
         self._append_global_identity_args(parser)
 
         return parser
 
-    def get_subcommand_parser(self, version):
-        parser = self.get_base_parser()
+    def get_subcommand_parser(self, version, argv):
+        parser = self.get_base_parser(argv)
 
         self.subcommands = {}
         subparsers = parser.add_subparsers(metavar='<subcommand>')
-        submodule = utils.import_versioned_module(version, 'shell')
+        submodule = importutils.import_versioned_module('muranoclient',
+                                                        version, 'shell')
         self._find_actions(subparsers, submodule)
         self._find_actions(subparsers, self)
 
-        self._add_bash_completion_subparser(subparsers)
-
         return parser
 
-    def _add_bash_completion_subparser(self, subparsers):
-        subparser = subparsers.add_parser(
-            'bash_completion',
-            add_help=False,
-            formatter_class=HelpFormatter
-        )
-        self.subcommands['bash_completion'] = subparser
-        subparser.set_defaults(func=self.do_bash_completion)
-
     def _find_actions(self, subparsers, actions_module):
         for attr in (a for a in dir(actions_module) if a.startswith('do_')):
             # I prefer to be hypen-separated instead of underscores.
@@ -274,13 +268,13 @@ class MuranoShell(object):
 
     def main(self, argv):
         # Parse args once to find version
-        parser = self.get_base_parser()
+        parser = self.get_base_parser(argv)
         (options, args) = parser.parse_known_args(argv)
         self._setup_logging(options.debug)
 
         # build available subcommands based on version
         api_version = options.murano_api_version
-        subcommand_parser = self.get_subcommand_parser(api_version)
+        subcommand_parser = self.get_subcommand_parser(api_version, argv)
         self.parser = subcommand_parser
 
         keystone_session = None
@@ -309,6 +303,9 @@ class MuranoShell(object):
                                    " or a token via --os-auth-token or"
                                    " env[OS_AUTH_TOKEN]")
 
+        if args.murano_packages_service == 'glance':
+            args.murano_packages_service = 'glare'
+
         if args.os_no_client_auth:
             if not args.murano_url:
                 raise exc.CommandError(
@@ -316,11 +313,11 @@ class MuranoShell(object):
                     " you must also specify a Murano API URL"
                     " via either --murano-url or env[MURANO_URL]")
             if (not args.glare_url and
-                    args.murano_packages_service in ['glance', 'glare']):
+                    args.murano_packages_service == 'glare'):
                 raise exc.CommandError(
                     "If you specify --os-no-client-auth and"
-                    " set murano-packages-service to 'glance'"
-                    " you must also specify a glance glare API URL"
+                    " set murano-packages-service to 'glare'"
+                    " you must also specify a glare API URL"
                     " via either --glare-url or env[GLARE_API]")
             if (not any([args.os_tenant_id, args.os_project_id]) and
                     args.murano_packages_service == 'glare'):
@@ -387,10 +384,13 @@ class MuranoShell(object):
             (v2_auth_url, v3_auth_url) = self._discover_auth_versions(
                 keystone_session, args.os_auth_url)
             if v3_auth_url:
-                args.os_project_domain_id = (args.os_project_domain_id or
-                                             'default')
-                args.os_user_domain_id = (args.os_user_domain_id or
-                                          'default')
+                if (not args.os_user_domain_id and
+                        not args.os_user_domain_name):
+                    args.os_user_domain_name = 'default'
+
+                if (not args.os_project_domain_id and
+                        not args.os_project_domain_name):
+                    args.os_project_domain_name = 'default'
 
             keystone_auth = AuthCLI.load_from_argparse_arguments(args)
 
@@ -440,11 +440,11 @@ class MuranoShell(object):
         if glance_client:
             kwargs['glance_client'] = glance_client
         else:
-            logger.warning("Could not initialise glance client. "
+            logger.warning("Could not initialize glance client. "
                            "Image creation will be unavailable.")
             kwargs['glance_client'] = None
 
-        if args.murano_packages_service in ['glance', 'glare']:
+        if args.murano_packages_service == 'glare':
             glare_endpoint = args.glare_url
 
             if not glare_endpoint:
@@ -488,7 +488,6 @@ class MuranoShell(object):
                 options.add(option)
 
         commands.remove('bash-completion')
-        commands.remove('bash_completion')
         print(' '.join(commands | options))
 
     @utils.arg('command', metavar='<subcommand>', nargs='?',
@@ -523,7 +522,7 @@ def main(args=sys.argv[1:]):
         if '--debug' in args or '-d' in args:
             raise
         else:
-            print(encodeutils.safe_encode(six.text_type(e)), file=sys.stderr)
+            print(encodeutils.safe_encode(str(e)), file=sys.stderr)
         sys.exit(1)
 
 
