@@ -13,15 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import io
 import json
 import os.path
 import tempfile
+from unittest import mock
 import zipfile
 
-import mock
 import requests
 import requests_mock
-import six
 import testtools
 import yaml
 
@@ -45,7 +45,7 @@ class FileTest(testtools.TestCase):
     def test_file_object_url_fails(self):
         resp = requests.Response()
         resp.status_code = 400
-        resp.raw = six.BytesIO(six.b("123"))
+        resp.raw = io.BytesIO(b"123")
 
         with mock.patch(
                 'requests.get',
@@ -55,7 +55,7 @@ class FileTest(testtools.TestCase):
 
     def test_file_object_url(self):
         resp = requests.Response()
-        resp.raw = six.BytesIO(six.b("123"))
+        resp.raw = io.BytesIO(b"123")
         resp.status_code = 200
         with mock.patch(
                 'requests.get',
@@ -70,13 +70,14 @@ def make_pkg(manifest_override, image_dicts=None):
         'Classes': {'foo': 'foo.yaml'},
         'Description': '',
         'Format': 1.0,
-        'FullName': '',
+        'FullName': 'org.foo',
         'Name': 'Apache HTTP Server',
         'Type': 'Application'}
     manifest.update(manifest_override)
-    file_obj = six.BytesIO()
+    file_obj = io.BytesIO()
     zfile = zipfile.ZipFile(file_obj, "a")
     zfile.writestr('manifest.yaml', yaml.dump(manifest))
+    zfile.writestr('Classes/foo.yaml', yaml.dump({}))
     if image_dicts:
         images_list = []
         default_image_spec = {
@@ -115,6 +116,14 @@ class PackageTest(testtools.TestCase):
             path=path,
         ).manifest['FullName'])
 
+    def test_package_from_directory(self):
+        path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
+                            "fixture_data/empty-app")
+        pkg = utils.Package(utils.File(path))
+        self.assertEqual('empty', pkg.manifest['FullName'])
+        pkg = utils.Package.from_location('', path=path)
+        self.assertEqual('empty', pkg.manifest['FullName'])
+
     @requests_mock.mock()
     def test_from_location_url(self, m):
         """Test that url overrides name specification."""
@@ -206,7 +215,7 @@ class PackageTest(testtools.TestCase):
         reqs = app.requirements(base_url=self.base_url)
 
         def key_position(key):
-            keys = list(six.iterkeys(reqs))
+            keys = list(iter(reqs.keys()))
             return keys.index(key)
 
         self.assertTrue(
@@ -256,7 +265,7 @@ class PackageTest(testtools.TestCase):
         reqs = app.requirements(base_url=self.base_url)
 
         def key_position(key):
-            keys = list(six.iterkeys(reqs))
+            keys = list(iter(reqs.keys()))
             return keys.index(key)
 
         self.assertTrue(
@@ -331,7 +340,7 @@ class PackageTest(testtools.TestCase):
         reqs = app.requirements(base_url=self.base_url)
 
         def key_position(key):
-            keys = list(six.iterkeys(reqs))
+            keys = list(iter(reqs.keys()))
             return keys.index(key)
 
         self.assertTrue(
@@ -369,7 +378,7 @@ class PackageTest(testtools.TestCase):
         reqs = app.requirements(base_url=self.base_url)
 
         def key_position(key):
-            keys = list(six.iterkeys(reqs))
+            keys = list(iter(reqs.keys()))
             return keys.index(key)
 
         self.assertTrue(
@@ -393,7 +402,7 @@ class PackageTest(testtools.TestCase):
 
     def test_file_object_repo_fails(self):
         resp = requests.Response()
-        resp.raw = six.BytesIO(six.b("123"))
+        resp.raw = io.BytesIO(b"123")
         resp.status_code = 400
         with mock.patch(
                 'requests.get',
@@ -406,10 +415,12 @@ class PackageTest(testtools.TestCase):
         self.assertRaises(ValueError, utils.Package.from_location,
                           name='foo.bar.baz', base_url='')
 
-    def test_file_object_repo(self):
+    @mock.patch.object(utils.Package, 'validate')
+    def test_file_object_repo(self, m_validate):
         resp = requests.Response()
-        resp.raw = six.BytesIO(six.b("123"))
+        resp.raw = io.BytesIO(b"123")
         resp.status_code = 200
+        m_validate.return_value = None
         with mock.patch(
                 'requests.get',
                 mock.Mock(side_effect=lambda k, *args, **kwargs: resp)):
@@ -423,7 +434,7 @@ class BundleTest(testtools.TestCase):
 
     @requests_mock.mock()
     def test_packages(self, m):
-        s = six.StringIO()
+        s = io.StringIO()
         bundle_contents = {'Packages': [
             {'Name': 'first_app'},
             {'Name': 'second_app', 'Version': '1.0'}
